<?php

namespace Teknisa\PED\Services;

use \Teknisa\Libs\Util\DateUtil;
use Teknisa\PED\Factories\ReservaPedidoFactory;

class ReservaPedidoService {

    protected $factory;

	public function __construct($factory){
	    $this->reservaPedidoFactory = $factory;
	}

    // Verifica se o almoxarifado está disponível para a venda.
    public function vericaAlmoxarifadoVenda($filial, $almoxarifado) {
        $infAlmoxarif = $this->reservaPedidoFactory->vericaAlmoxarifadoVenda($filial, $almoxarifado);
        if ($infAlmoxarif[0]['IDDISPCONPED'] == 'S') {
            return true;
        } else {
            return false;
        }
    }
    
    // Verifica se o almoxarifado está parametrizado corretamente no local de estoque por produto.
    public function verificaAlmoxarifadoLoteProduto($cdfilial, $cdproduto) {
        $infAlmoxarif = $this->reservaPedidoFactory->retornaAlmoxarifadoLoteProduto($cdfilial, $cdproduto);
        
        
        if (isset($infAlmoxarif[0]) && !empty($infAlmoxarif[0]) && $infAlmoxarif[0]['CDALMOXPRCLI']){
            return true;
        } else {
            return false;
        }
    } 

    // Retorna se a filial controla almoxarifado, localestoque e lote.
    public function retornaDadosFilial($cdfilial) {
        $infAlmoxarif = $this->reservaPedidoFactory->retornaDadosFilial($cdfilial);
        return $infAlmoxarif;
    }
    
    public function retornaAlmoxarifadoLoteProduto($cdfilial, $cdproduto) {
        $infAlmoxarif = $this->reservaPedidoFactory->retornaAlmoxarifadoLoteProduto($cdfilial, $cdproduto);
        return $infAlmoxarif;
    }

    public function retornaLoteProduto($cdfilial, $cdproduto) {
        $lotesProd = $this->reservaPedidoFactory->retornaLoteProduto($cdfilial, $cdproduto);
        return $lotesProd;
    }
    // Verificar também se o lote está dentro da validade.
    public function vericaValidadeLote($cdfilial, $nrloteestq, $nrsublote, $cdproduto) {
        $isAlmoxValid = $this->reservaPedidoFactory->vericaValidadeLote($cdfilial, $nrloteestq, $nrsublote, $cdproduto);
        $dataAtual = DateUtil::getDataAtual();  //->format('d/m/Y H:i:s')
        
        $isAlmoxValid = DateUtil::getDataDeString($isAlmoxValid[0]['DTVALILOTE'], "d/m/Y H:i:s");
        $isValid = DateUtil::comparaDatas($dataAtual, $isAlmoxValid, 1);
        if ($isValid) {
            return true;
        } else {
            return false;
        }
    }
    
    public function retornaLotesValidos($dtatual, $cdproduto, $cdfilial) {
        $data = $this->reservaPedidoFactory->retornaLotesValidos($dtatual, $cdproduto, $cdfilial);
        return $data;
    }

    public function buscaEstoque($cdfilial, $nrpedido, $nritemped, $cdproduto, $cdalmoxarife = ' ', $cdlocalestoq = ' ') {
        $data = $this->reservaPedidoFactory->buscaEstoque($cdfilial, $nrpedido, $nritemped, $cdproduto, $cdalmoxarife, $cdlocalestoq);
        return $data;
    }
    public function buscaEstoqueAlmox($cdfilial, $nrpedido, $nritemped, $cdproduto, $cdalmoxarife = ' ', $cdlocalestoq = ' ') {
        $data = $this->reservaPedidoFactory->buscaEstoqueAlmox($cdfilial, $nrpedido, $nritemped, $cdproduto, $cdalmoxarife, $cdlocalestoq);
        return $data;
    }
}